==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/DatalakeworkspacepermissionCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Datalakeworkspacepermission;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DatalakeworkspacepermissionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class DatalakeworkspacepermissionCollectionRequest extends CollectionPageEntityRequest<Datalakeworkspacepermission, DatalakeworkspacepermissionRequest>{

    protected ContextPath contextPath;

    public DatalakeworkspacepermissionCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Datalakeworkspacepermission.class, cp -> new DatalakeworkspacepermissionRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest datalakeworkspacepermission_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest datalakeworkspacepermission_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("datalakeworkspacepermission_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest datalakeworkspacepermission_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest datalakeworkspacepermission_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("datalakeworkspacepermission_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest datalakeworkspacepermission_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest datalakeworkspacepermission_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("datalakeworkspacepermission_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest datalakeworkspacepermission_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest datalakeworkspacepermission_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("datalakeworkspacepermission_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest datalakeworkspacepermission_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest datalakeworkspacepermission_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("datalakeworkspacepermission_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest datalakeworkspacepermission_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest datalakeworkspacepermission_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("datalakeworkspacepermission_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest datalakeworkspacepermission_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest datalakeworkspacepermission_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("datalakeworkspacepermission_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest datalakeworkspacepermission_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest datalakeworkspacepermission_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("datalakeworkspacepermission_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/DatalakeworkspacepermissionCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Datalakeworkspacepermission;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DatalakeworkspacepermissionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class DatalakeworkspacepermissionCollectionRequest extends CollectionPageEntityRequest<Datalakeworkspacepermission, DatalakeworkspacepermissionRequest>{

    protected ContextPath contextPath;

    public DatalakeworkspacepermissionCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Datalakeworkspacepermission.class, cp -> new DatalakeworkspacepermissionRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest datalakeworkspacepermission_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest datalakeworkspacepermission_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("datalakeworkspacepermission_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest datalakeworkspacepermission_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest datalakeworkspacepermission_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("datalakeworkspacepermission_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest datalakeworkspacepermission_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest datalakeworkspacepermission_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("datalakeworkspacepermission_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest datalakeworkspacepermission_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest datalakeworkspacepermission_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("datalakeworkspacepermission_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest datalakeworkspacepermission_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest datalakeworkspacepermission_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("datalakeworkspacepermission_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest datalakeworkspacepermission_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest datalakeworkspacepermission_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("datalakeworkspacepermission_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest datalakeworkspacepermission_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest datalakeworkspacepermission_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("datalakeworkspacepermission_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest datalakeworkspacepermission_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("datalakeworkspacepermission_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest datalakeworkspacepermission_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("datalakeworkspacepermission_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

}
